# Mathician
<img height="200" width="200" src="https://cdn.discordapp.com/attachments/980115259534749746/984839027398160394/Untitled.png"/>


[![Top Language](https://img.shields.io/github/languages/top/ArjunSharda/Mathician)](https://python.org)
[![License](https://img.shields.io/github/license/ajsharda17/Mathician?color=l&label=License)](https://github.com/ArjunSharda/Mathician/blob/latest-public-release/LICENSE)
![GitHub commit activity (per year)](https://img.shields.io/github/commit-activity/y/ArjunSharda/Mathician)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/ArjunSharda/Mathician/Dependency%20Review?label=workflow)
![Total GitHub Contributors](https://img.shields.io/github/contributors/ArjunSharda/Mathician?label=total%20contributors)

Mathician is a math package that uses the math library (some of it) and built with Python math classes. It is created by Arjun Sharda, and it is one simple python package that can be used, although very basic and does not have many features. 

Mathician is open-sourced and is free for everyone to use, fork, etc, under the repository's license.

In short, Mathician is a basic math package with not a lot of features and uses the math library. It is a python package created by Arjun Sharda and can be installed with the PyPi package manager, though.


**Changelog**

Version 1.5.0

+ Code rewrite for publishing with PyPi


**Quickstart**
```python
import mathician
print(mathician.add(100, 2))
```

Take a look at more examples in the [examples](https://github.com/ArjunSharda/Mathician/tree/latest-public-release/examples) folder!
